# Changelog

## 0.3.0 (2026-02-05)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/fragment-dev/fragment-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** breaking API changes ([4a6e374](https://github.com/fragment-dev/fragment-py/commit/4a6e3749f2d98bddf436e07ba849d2e2c7073dc6))

## 0.2.0 (2026-02-03)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/fragment-dev/fragment-py/compare/v0.1.0...v0.2.0)

### Features

* **api:** OpenAPI spec update via Stainless ([#4](https://github.com/fragment-dev/fragment-py/issues/4)) ([6dd1723](https://github.com/fragment-dev/fragment-py/commit/6dd17231504a28f7a5008d5c54c7eabff8910a16))

## 0.1.0 (2026-02-02)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/fragment-dev/fragment-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([6ed6c9f](https://github.com/fragment-dev/fragment-py/commit/6ed6c9fb6f1c6e4a0d90661a2f45086d4693ecd3))
* **api:** api update ([a36f59b](https://github.com/fragment-dev/fragment-py/commit/a36f59b2fad84a8a62431018e062c911b9f6284f))


### Bug Fixes

* **client/oauth:** send grant_type in the right location ([da1f6db](https://github.com/fragment-dev/fragment-py/commit/da1f6db06f11bf666fa02a2fc01535b6e628f2ce))


### Chores

* configure new SDK language ([32d4975](https://github.com/fragment-dev/fragment-py/commit/32d4975e21ad1144cdc047e8bb7eb8c7a202a239))
* update SDK settings ([5b46542](https://github.com/fragment-dev/fragment-py/commit/5b46542034f3fef7df86b372d20ca5bd68cc3613))
* update SDK settings ([dceb203](https://github.com/fragment-dev/fragment-py/commit/dceb2030cfd3b47037ae0365fffa4d71ba418919))
* update SDK settings ([931490f](https://github.com/fragment-dev/fragment-py/commit/931490fb3310f3348befc5a6df33ae0813149e16))
* update SDK settings ([6a2ba6c](https://github.com/fragment-dev/fragment-py/commit/6a2ba6c1b775d248c3cb1743d0d2de34885eae5c))
* update SDK settings ([b141e78](https://github.com/fragment-dev/fragment-py/commit/b141e789dbae9df530ea965d4473cc67b400a4e1))
* update SDK settings ([0ecf9e6](https://github.com/fragment-dev/fragment-py/commit/0ecf9e650956e9f73b80a899ce2b51811445ed20))
* update SDK settings ([399dc85](https://github.com/fragment-dev/fragment-py/commit/399dc851eeac705826d88c49a4bece529011c91b))
